| Title: | Large datasets for spatial analysis |
|---|---|
| Description: | Large datasets for spatial analysis. The data from this package could be retrived using the spData package. |
| Authors: | Jakub Nowosad [aut, cre], Robin Lovelace [aut], Jannes Muenchow [ctb] |
| Maintainer: | Jakub Nowosad <[email protected]> |
| License: | CC0 |
| Version: | 2.2.0 |
| Built: | 2026-05-27 07:38:15 UTC |
| Source: | https://github.com/Nowosad/spDataLarge |
Data used in the transport chapter in Geocomputation with R. See https://r.geocompx.org/transport.html for details.
bristol_waysbristol_ways
sf data frame objects
https://wicid.ukdataservice.ac.uk/ and other open access sources
## Not run: library(sf) bristol_ways bristol_od bristol_region bristol_ttwa bristol_zones bristol_stations ## End(Not run)## Not run: library(sf) bristol_ways bristol_od bristol_region bristol_ttwa bristol_zones bristol_stations ## End(Not run)
Data used in the geomarketing chapter in Geocomputation with R. See https://r.geocompx.org/location.html for details.
census_de metro_names shopscensus_de metro_names shops
A data.frame with census variables
A data.frame with metropolitan area information
An sf data.frame with POINT geometry
An object of class data.frame with 10 rows and 3 columns.
An object of class sf (inherits from data.frame) with 180035 rows and 3 columns.
A data.frame with German census data at 1km resolution. Contains columns: x, y (EPSG:3035 coordinates), pop (population count, 2022), women (percentage of women, 2011), mean_age (mean age in years, 2022), hh_size (average household size, 2022). Missing values are coded as -1.
A data.frame with metropolitan area names derived from Census 2022 population data. Contains columns: city, town, state. Generated by aggregating 1km population grid to 20km resolution, filtering cells with >500,000 inhabitants, and reverse geocoding centroids.
An sf data.frame of shop locations from OpenStreetMap for the identified metropolitan areas. Contains columns: osm_id, shop, geometry.
data("census_de", package = "spDataLarge") head(census_de) data("metro_names", package = "spDataLarge") metro_names data("shops", package = "spDataLarge") head(shops)data("census_de", package = "spDataLarge") head(census_de) data("metro_names", package = "spDataLarge") metro_names data("shops", package = "spDataLarge") head(shops)
A community matrix with species as columns and sites as rows. The rownames correspond to the id which can be also found in [random_points]. Please note that in fact 100 sites have been visited but in 16 of them no species could be found (see again [random_points]). The data is used in the "Ecology" chapter in Geocomputation with R. See https://r.geocompx.org/eco.html for details.
A dataframe with 100 sites (rows) and 69 species (columns). Species presence is given in percentage points (between 0-100 site). Due to overlapping cover between individual plants, the total cover per site can be >100%.
Muenchow, J., Bräuning, A., Rodríguez, E.F. & von Wehrden, H. (2013): Predictive mapping of species richness and plant species' distributions of a Peruvian fog oasis along an altitudinal gradient. Biotropica 45, 5, 557-566, doi: 10.1111/btp.12049.
data("comm", package = "spDataLarge")data("comm", package = "spDataLarge")
A raster geotiff (EPSG:32717) representing altitude (ASTER GDEM, LP DAAC 2012) with 117 rows and 117 columns:
Altitude in m asl.
. For more details, please refer to Muenchow et al. (2013).. The data is used in the "Ecology" chapter in Geocomputation with R. See https://r.geocompx.org/eco.html for details.
A geotiff file
Muenchow, J., Bräuning, A., Rodríguez, E.F. & von Wehrden, H. (2013): Predictive mapping of species richness and plant species' distributions of a Peruvian fog oasis along an altitudinal gradient. Biotropica 45, 5, 557-566, doi: 10.1111/btp.12049.
LP DAAC (2012): Land Processes Distributed Active Archive Center, located at the U.S. Geological Survey (USGS) Earth Resources Observation and Science (EROS) Center. Available at: https://lpdaac.usgs.gov/ (last accessed 25 January 2012).
system.file("raster/ndvi.tif", package = "spDataLarge")system.file("raster/ndvi.tif", package = "spDataLarge")
A geotiff file (CRS: UTM zone 17S; EPSG:32717) with 117 rows and 117 columns:
dem Digital elevation model (ASTER GDEM, LP DAAC 2012), see also [spDataLarge::dem].
ndvi Normalized Differenced Vegetation index.
carea Catchment area.
cslope Catchment slope
The data is used in the "Ecology" chapter in Geocomputation with R. See https://r.geocompx.org/eco.html for details.
A geotiff file
LP DAAC (2012): Land Processes Distributed Active Archive Center, located at the U.S. Geological Survey (USGS) Earth Resources Observation and Science (EROS) Center. Available at: https://lpdaac.usgs.gov/ (last accessed 25 January 2012).
Muenchow, J., Brauning, A., Rodriguez, E.F. & von Wehrden, H. (2013): Predictive mapping of species richness and plant species' distributions of a Peruvian fog oasis along an altitudinal gradient. Biotropica 45, 5, 557-566, doi: 10.1111/btp.12049.
Muenchow, J., Schratz, P., and A. Brenning. 2017. RQGIS: Integrating R with QGIS for Statistical Geocomputing. The R Journal 9, 2, 409-428. https://rjournal.github.io/archive/2017/RJ-2017-067/RJ-2017-067.pdf.
system.file("raster/ep.tif", package = "spDataLarge")system.file("raster/ep.tif", package = "spDataLarge")
This is a dataset containing the four bands (2, 3, 4, 5) of the Landsat 8 image for the area of Zion National Park. A scale factor should be applied before using the data: https://www.usgs.gov/faqs/how-do-i-use-a-scale-factor-landsat-level-2-science-products
A multilayer geotiff file
http://landsat-pds.s3.amazonaws.com/L8/038/034/LC80380342015230LGN00/
system.file("raster/landsat.tif", package = "spDataLarge")system.file("raster/landsat.tif", package = "spDataLarge")
Data used in the "Bridges to GIS" chapter in Geocomputation with R. See https://r.geocompx.org/gis.html for details.
london_streetslondon_streets
An sf-object with one attribute (osm_id) and one geometry column.
OpenStreetMap (see https://www.openstreetmap.org/).
## Not run: library(sf) library(osmdata) library(spData) library(dplyr) data(cycle_hire) points = cycle_hire[1:25, ] b_box = sf::st_bbox(points) london_streets = opq(b_box) %>% add_osm_feature(key = "highway") %>% osmdata_sf() %>% `[[`("osm_lines") london_streets = dplyr::select(london_streets, 1) ## End(Not run)## Not run: library(sf) library(osmdata) library(spData) library(dplyr) data(cycle_hire) points = cycle_hire[1:25, ] b_box = sf::st_bbox(points) london_streets = opq(b_box) %>% add_osm_feature(key = "highway") %>% osmdata_sf() %>% `[[`("osm_lines") london_streets = dplyr::select(london_streets, 1) ## End(Not run)
Data used in the "Statistical learning for geographic data" chapter in Geocomputation with R. See https://r.geocompx.org/spatial-cv.html for details.
lsllsl
The landslide dataset consists of two objects (CRS: UTM zone 17S; EPSG:32717):
lsl A data.frame object representing the coordinates of landslide initiation points with 350 rows and 8 columns.
study_mask An sf-object delineating the natural part of the study area.
Landslide dataset of the RSAGA package: data("landslides", package = "RSAGA").
Landslide Data:
Muenchow, J., Brenning, A., Richter, R. (2012): Geomorphic process rates of landslides along a humidity gradient in the tropical Andes, Geomorphology 139-140, 271-284. DOI: 10.1016/j.geomorph.2011.10.029.
Stoyan, R. (2000): Aktivitaet, Ursachen und Klassifikation der Rutschungen in San Francisco/Suedecuador. Unpublished diploma thesis, University of Erlangen-Nuremberg, Germany.
?ta.tif
data("lsl", "study_mask", package = "spDataLarge")data("lsl", "study_mask", package = "spDataLarge")
NDVI raster geotiff (EPSG:32717) computed from a Landsat scene (path 9, row 67, acquisition date: 09/22/2000; USGS 2013) with 117 rows and 117 columns:
Normalized difference vegetation index.
. For more details, please refer to Muenchow et al. (2013).. The data is used in the "Ecology" chapter in Geocomputation with R. See https://r.geocompx.org/eco.html for details.
A geotiff file
Muenchow, J., Bräuning, A., Rodríguez, E.F. & von Wehrden, H. (2013): Predictive mapping of species richness and plant species' distributions of a Peruvian fog oasis along an altitudinal gradient. Biotropica 45, 5, 557-566, doi: 10.1111/btp.12049.
USGS (2013): U.S. Geological Survey. Earth Explorer. Available at: http://earthexplorer.usgs.gov/ (last accessed 1 March 2013).
system.file("raster/ndvi.tif", package = "spDataLarge")system.file("raster/ndvi.tif", package = "spDataLarge")
This is a dataset containing a simplified version of the National Land Cover Database 2011 product for the Zion National Park area
A geotiff file
https://www.mrlc.gov/nlcd2011.php
system.file("raster/nlcd.tif", package = "spDataLarge")system.file("raster/nlcd.tif", package = "spDataLarge")
This is a dataset containing the National Land Cover Database 2011 product for the Zion National Park area
A geotiff file
https://www.mrlc.gov/nlcd2011.php
system.file("raster/nlcd2011.tif", package = "spDataLarge")system.file("raster/nlcd2011.tif", package = "spDataLarge")
Elevation raster data of the New Zealand area from the Mapzen Terrain Service. For teaching purposes only
A geotiff file
https://registry.opendata.aws/terrain-tiles/
See the elevatr package: https://cran.r-project.org/web/packages/elevatr
system.file("raster/nz_elev.tif", package = "spDataLarge")system.file("raster/nz_elev.tif", package = "spDataLarge")
Polish Presidential election 2015 data by gminy and Warsaw borough areal units
pol_pres15pol_pres15
sf data frame object with 2495 areal units and 65 variables
TERYT, TERYT0, gm0TERYT areal unit IDs
name0original areal unit names
namecleaned areal unit names
typesfactor with levels “Rural”, “Urban”, “Urban/rural” and “Warsaw borough”
I_turnoutFirst round turnout proportion
II_turnoutRunoff round turnout proportion
I_Duda_shareWinner first round share
II_Duda_shareWinner runoff round share
I_Komorowski_shareIncumbent first round share
II_Komorowski_shareIncumbent runoff round share
I_*First round aggregated counts of all polling station data
II_*Runoff round aggregated counts of all polling station data
“PVE” in variable names means “postal voting envelopes”; voters requesting a postal voting package are expected to return a postal voting envelope with a declaration, and a sealed voting envelope to be placed in the ballot box.
Roger Bivand
http://prezydent2015.pkw.gov.pl/319_Pierwsze_glosowanie/, http://prezydent2015.pkw.gov.pl/325_Ponowne_glosowanie/, https://www.gov.pl/web/gugik
## Not run: data("pol_pres15", package = "spDataLarge") wd = aggregate(pol_pres15$I_entitled_to_vote, list(pol_pres15$types), sum)$x boxplot(I_turnout ~ types, data = pol_pres15, width = wd) ## End(Not run)## Not run: data("pol_pres15", package = "spDataLarge") wd = aggregate(pol_pres15$I_entitled_to_vote, list(pol_pres15$types), sum)$x boxplot(I_turnout ~ types, data = pol_pres15, width = wd) ## End(Not run)
An [sf] (EPSG:32717) object with 100 randomly sampled points (stratified by altitude) on the Mt. Mongón (Peru). For more details, please refer to Muenchow et al. (2013). The data is used in the "Ecology" chapter in Geocomputation with R. See https://r.geocompx.org/eco.html for details.
An [sf] object with 100 rows and 3 variables:
Plot ID.
Number of vascular plant species per plot (species richness).
Simple feature point geometry.
Muenchow, J., Bräuning, A., Rodríguez, E.F. & von Wehrden, H. (2013): Predictive mapping of species richness and plant species' distributions of a Peruvian fog oasis along an altitudinal gradient. Biotropica 45, 5, 557-566, doi: 10.1111/btp.12049.
data("random_points", package = "spDataLarge")data("random_points", package = "spDataLarge")
This is a dataset containing the elevation raster data from SRTM of the Zion National Park area
A geotiff file
https://srtm.csi.cgiar.org/SRT-ZIP/SRTM_V41/SRTM_Data_GeoTiff/srtm_14_05.zip
system.file("raster/srtm.tif", package = "spDataLarge")system.file("raster/srtm.tif", package = "spDataLarge")
An [sf] (EPSG:32717) object of geometry class polygon.
An [sf] object with 1 row and 2 variables:
Name.
Simple feature polygon geometry.
Muenchow, J., Bräuning, A., Rodríguez, E.F. & von Wehrden, H. (2013): Predictive mapping of species richness and plant species' distributions of a Peruvian fog oasis along an altitudinal gradient. Biotropica 45, 5, 557-566, doi: 10.1111/btp.12049.
data("study_area", package = "spDataLarge")data("study_area", package = "spDataLarge")
Data used in the "Statistical learning for geographic data" chapter in Geocomputation with R. See https://r.geocompx.org/spatial-cv.html for details.
A geotiff file with the five terrain attribute layers: slope, plan curvature, profile curvature, elevation and catchment area.
DEM dataset of the RSAGA package: data("landslides",
package = "RSAGA").
DEM:
Ungerechts, L. (2010): DEM 10m (triangulated from aerial photo - b/w). Available online:
'http://www.tropicalmountainforest.org/data_pre.do?citid=901'
Jordan, E., Ungerechts, L., Caceres, B. Penafiel, A. and Francou, B. (2005): Estimation by photogrammetry of the glacier recession on the Cotopaxi Volcano (Ecuador) between 1956 and 1997. *Hydrological Sciences* 50, 949-961.
?lsl
system.file("raster/ta.tif", package = "spDataLarge")system.file("raster/ta.tif", package = "spDataLarge")
Dataset containing 30 randomly located points in the Zion National Park
zion_pointszion_points
A sf object
Dataset containing 30 randomly located points in the Zion National Park
A geopackage file
https://irma.nps.gov/DataStore/DownloadFile/580617
system.file("vector/zion_points.gpkg", package = "spDataLarge")system.file("vector/zion_points.gpkg", package = "spDataLarge")
This is a dataset containing the borders of Zion National Park
A geopackage file
https://irma.nps.gov/DataStore/DownloadFile/580617
system.file("vector/zion.gpkg", package = "spDataLarge")system.file("vector/zion.gpkg", package = "spDataLarge")